import 'package:ambito/main.dart';
import 'package:ambito/src/entity/_general/filter/item_filter.dart';
import 'package:ambito/src/entity/measure/measure_repository.dart';
import 'package:flutter/material.dart';

import '../../consts/consts.dart';
import '../../widgets/appbar/ambito_appbar.dart';

class CalendarPageYear extends StatefulWidget {
  const CalendarPageYear({super.key});

  @override
  State<StatefulWidget> createState() => CalendarPageYearState();
}

class CalendarPageYearState extends State<CalendarPageYear> {
  List<TableRow> rowsBody = <TableRow>[];
  List<TableRow> rowsHeader = <TableRow>[];

  Set<String> displayFilterSet = {'creation', 'maintenance'};

  List<FilterChip> displayFilters = [];
  List<ItemFilter>? monthFilter = [];

  @override
  void initState() {
    initDataSource();
    super.initState();
  }

  initDataSource() {
    List<TableCell> cells = [
      TableCell(
        child: Padding(
          padding: const EdgeInsets.all(8),
          child: Text(
            'Maßnahme',
            style: baseTheme.currentThemeData.textTheme.titleMedium
                ?.copyWith(fontWeight: FontWeight.bold, color: Colors.white),
          ),
        ),
      ),
    ];
    for (String month in months) {
      cells.add(
        TableCell(
          verticalAlignment: TableCellVerticalAlignment.middle,
          child: Text(
            textAlign: TextAlign.center,
            month,
            style: baseTheme.currentThemeData.textTheme.titleMedium
                ?.copyWith(fontWeight: FontWeight.bold, color: Colors.white),
          ),
        ),
      );
    }
    rowsHeader.add(TableRow(
        decoration: const BoxDecoration(color: Color(0xFF60845E)),
        children: cells));
    var massnahmen = MeasureRepository().getAllOrdered();
    for (var massnahme in massnahmen) {
      if (massnahme.name != null && massnahme.name!.isNotEmpty) {
        cells = [
          TableCell(
            child: Padding(
              padding: const EdgeInsets.all(8),
              child: Text(
                massnahme.name!,
              ),
            ),
          ),
        ];
        for (String month in months) {
          if (massnahme.timeFrame!
              .where((ele) => ele.value == month)
              .isNotEmpty) {
            cells.add(
              TableCell(
                child: Container(
                  width: double.infinity,
                  height: 44,
                  color: baseTheme.currentColorScheme.primary,
                ),
              ),
            );
          } else {
            cells.add(
              TableCell(
                child: Container(
                  width: double.infinity,
                  height: 44,
                  color: Colors.transparent,
                ),
              ),
            );
          }
        }
        rowsBody.add(
          TableRow(
            children: cells,
          ),
        );
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    double fixedWidth = 120;
    return Scaffold(
      appBar: AmbitoAppbar(
        links: const ['dashboard', 'massnahmen'],
      ),
      body: Card(
        child: Column(
          children: [
            /*Padding(
            padding: const EdgeInsets.only(top: 32, left: 32, right: 32),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.end,
              children: [
                FilterChip(
                  label: const Text('Zeitraum der Anlage'),
                  selected: displayFilterSet.contains('creation'),
                  selectedColor: baseTheme.currentColorScheme.primary,
                  onSelected: (bool selected) {
                    setState(() {
                      if (selected) {
                        displayFilterSet.add('creation');
                      } else {
                        displayFilterSet.remove('creation');
                      }
                    });
                  },
                ),
                baseTheme.horizontalSpacerSmall,
                FilterChip(
                  label: const Text('Zeitraum der Pflege'),
                  selected: displayFilterSet.contains('maintenance'),
                  selectedColor: baseTheme.currentColorScheme.inversePrimary,
                  onSelected: (bool selected) {
                    setState(() {
                      if (selected) {
                        displayFilterSet.add('maintenance');
                      } else {
                        displayFilterSet.remove('maintenance');
                      }
                    });
                  },
                ),
              ],
            ),
          ),*/
            Padding(
              padding: const EdgeInsets.only(top: 32, left: 32, right: 32),
              child: _buildTableHeader(fixedWidth),
            ),
            Expanded(
              child: SingleChildScrollView(
                child: Padding(
                  padding:
                      const EdgeInsets.only(bottom: 32, left: 32, right: 32),
                  child: _buildTableBody(fixedWidth),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }

  Table _buildTableHeader(double fixedWidth) {
    TableBorder tableBorder = TableBorder(
      top: const BorderSide(
        width: 2,
        color: Colors.black,
      ),
      left: const BorderSide(
        width: 2,
        color: Colors.black,
      ),
      right: const BorderSide(
        width: 2,
        color: Colors.black,
      ),
      bottom: const BorderSide(
        width: 2,
        color: Colors.black,
      ),
      horizontalInside: BorderSide(
        width: 1,
        color: Colors.black.withOpacity(.6),
      ),
      verticalInside: const BorderSide(
        width: 0,
        color: Colors.transparent,
      ),
    );
    return _getTable(fixedWidth, tableBorder, rowsHeader);
  }

  Table _buildTableBody(double fixedWidth) {
    TableBorder tableBorder = TableBorder(
      top: const BorderSide(
        width: 0,
        color: Colors.black,
      ),
      left: const BorderSide(
        width: 2,
        color: Colors.black,
      ),
      right: const BorderSide(
        width: 2,
        color: Colors.black,
      ),
      bottom: const BorderSide(
        width: 2,
        color: Colors.black,
      ),
      horizontalInside: BorderSide(
        width: 1,
        color: Colors.black.withOpacity(.6),
      ),
      verticalInside: const BorderSide(
        width: 0,
      ),
    );
    return _getTable(fixedWidth, tableBorder, rowsBody);
  }

  Table _getTable(
      double fixedWidth, TableBorder tableBorder, List<TableRow> rows) {
    return Table(
      border: tableBorder,
      columnWidths: <int, TableColumnWidth>{
        0: const FlexColumnWidth(300),
        1: FlexColumnWidth(fixedWidth),
        2: FlexColumnWidth(fixedWidth),
        3: FlexColumnWidth(fixedWidth),
        4: FlexColumnWidth(fixedWidth),
        5: FlexColumnWidth(fixedWidth),
        6: FlexColumnWidth(fixedWidth),
        7: FlexColumnWidth(fixedWidth),
        8: FlexColumnWidth(fixedWidth),
        9: FlexColumnWidth(fixedWidth),
        10: FlexColumnWidth(fixedWidth),
        11: FlexColumnWidth(fixedWidth),
        12: FlexColumnWidth(fixedWidth),
        13: FlexColumnWidth(fixedWidth),
      },
      children: rows,
    );
  }
}
